
#ifndef _C16_co763_
#define _C16_co763_

#ifdef __cplusplus
extern "C" {
#endif

extern EIF_BOOLEAN F233_2861(EIF_REFERENCE, EIF_REFERENCE, EIF_REFERENCE);
extern void EIF_Minit763(void);
extern char *(*R3851[])();

#ifdef __cplusplus
}
#endif

#endif
